==> mca_flutter_sdk-0.0.3.tar.gz: lib/src/widgets/buttons.dart <==
import 'package:flutter/material.dart';

import '../theme.dart';

Widget button({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(0, 15, 0, 15),
        child: Center(
            child: Text(
              text ?? '',
              style: const TextStyle(
                  color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);

Widget successButton({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.all(20),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            const SizedBox(width: 20),
            Center(
                child: Text(
                  text ?? '',
                  style: const TextStyle(
                      color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
                )),
            const Icon(Icons.arrow_forward, color: WHITE, size: 16),
          ],
        ),
      ),
    ),
  ),
);

Widget closeButton({onTap, color}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child:const Padding(
        padding:  EdgeInsets.fromLTRB(0,20,0,20),
        child:   Center(
            child: Text(
               'Yes, I want to',
              style:  TextStyle(
                  color: WHITE, fontSize: 12, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);

Widget dialogButton({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(20, 14, 20, 14),
        child: Center(
            child: Text(
              text ?? '',
              style: const TextStyle(
                  color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);

==> mca_flutter_sdk-0.5.0.tar.gz: lib/src/widgets/buttons.dart <==
import 'package:flutter/material.dart';

import '../theme.dart';

Widget button({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(0, 15, 0, 15),
        child: Center(
            child: Text(
              text ?? '',
              style: const TextStyle(
                  color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);

Widget successButton({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.all(20),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            const SizedBox(width: 20),
            Center(
                child: Text(
                  text ?? '',
                  style: const TextStyle(
                      color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
                )),
            const Icon(Icons.arrow_forward, color: WHITE, size: 16),
          ],
        ),
      ),
    ),
  ),
);

Widget closeButton({onTap, color,text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding:const  EdgeInsets.fromLTRB(0,20,0,20),
        child:   Center(
            child: Text(
              text?? 'Yes, I want to',
              style:const  TextStyle(
                  color: WHITE, fontSize: 12, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);

Widget dialogButton({onTap, color, text}) => Padding(
  padding: const EdgeInsets.fromLTRB(0, 8, 0, 8),
  child: InkWell(
    onTap: onTap,
    child: Container(
      decoration: BoxDecoration(
        color: PRIMARY,
        borderRadius: BorderRadius.circular(6),
      ),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(20, 14, 20, 14),
        child: Center(
            child: Text(
              text ?? '',
              style: const TextStyle(
                  color: WHITE, fontSize: 14, fontWeight: FontWeight.w600),
            )),
      ),
    ),
  ),
);
